import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext, useEffect, useMemo } from 'react';
import { CompositionManager } from './CompositionManagerContext.js';
import { truthy } from './truthy.js';
import { validateFolderName } from './validation/validate-folder-name.js';
export const FolderContext = createContext({
    folderName: null,
    parentName: null,
});
/**
 * @description By wrapping a <Composition /> inside a <Folder />, you can visually categorize it in your sidebar, should you have many compositions.
 * @see [Documentation](https://www.remotion.dev/docs/folder)
 */
export const Folder = ({ name, children, }) => {
    const parent = useContext(FolderContext);
    const { registerFolder, unregisterFolder } = useContext(CompositionManager);
    validateFolderName(name);
    const parentNameArr = [parent.parentName, parent.folderName].filter(truthy);
    const parentName = parentNameArr.length === 0 ? null : parentNameArr.join('/');
    const value = useMemo(() => {
        return {
            folderName: name,
            parentName,
        };
    }, [name, parentName]);
    useEffect(() => {
        registerFolder(name, parentName);
        return () => {
            unregisterFolder(name, parentName);
        };
    }, [name, parent.folderName, parentName, registerFolder, unregisterFolder]);
    return (_jsx(FolderContext.Provider, { value: value, children: children }));
};
