import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useLayoutEffect, useMemo, useRef, useState, } from 'react';
import { CompositionManagerProvider } from './CompositionManager.js';
import { EditorPropsProvider } from './EditorProps.js';
import { NativeLayersProvider } from './NativeLayers.js';
import { BufferingProvider } from './buffering.js';
import { continueRender, delayRender } from './delay-render.js';
import { NonceContext } from './nonce.js';
import { PrefetchProvider } from './prefetch-state.js';
import { random } from './random.js';
import { SetTimelineContext, TimelineContext, getInitialFrameState, } from './timeline-position-state.js';
import { DurationsContextProvider } from './video/duration-state.js';
export const RemotionRoot = ({ children, numberOfAudioTags }) => {
    const [remotionRootId] = useState(() => String(random(null)));
    const [frame, setFrame] = useState(() => getInitialFrameState());
    const [playing, setPlaying] = useState(false);
    const imperativePlaying = useRef(false);
    const [fastRefreshes, setFastRefreshes] = useState(0);
    const [playbackRate, setPlaybackRate] = useState(1);
    const audioAndVideoTags = useRef([]);
    if (typeof window !== 'undefined') {
        // eslint-disable-next-line react-hooks/rules-of-hooks
        useLayoutEffect(() => {
            window.remotion_setFrame = (f, composition, attempt) => {
                window.remotion_attempt = attempt;
                const id = delayRender(`Setting the current frame to ${f}`);
                setFrame((s) => ({
                    ...s,
                    [composition]: f,
                }));
                requestAnimationFrame(() => continueRender(id));
            };
            window.remotion_isPlayer = false;
        }, []);
    }
    const timelineContextValue = useMemo(() => {
        return {
            frame,
            playing,
            imperativePlaying,
            rootId: remotionRootId,
            playbackRate,
            setPlaybackRate,
            audioAndVideoTags,
        };
    }, [frame, playbackRate, playing, remotionRootId]);
    const setTimelineContextValue = useMemo(() => {
        return {
            setFrame,
            setPlaying,
        };
    }, []);
    const nonceContext = useMemo(() => {
        let counter = 0;
        return {
            getNonce: () => counter++,
            fastRefreshes,
        };
    }, [fastRefreshes]);
    useEffect(() => {
        if (typeof __webpack_module__ !== 'undefined') {
            if (__webpack_module__.hot) {
                __webpack_module__.hot.addStatusHandler((status) => {
                    if (status === 'idle') {
                        setFastRefreshes((i) => i + 1);
                    }
                });
            }
        }
    }, []);
    return (_jsx(NonceContext.Provider, { value: nonceContext, children: _jsx(TimelineContext.Provider, { value: timelineContextValue, children: _jsx(SetTimelineContext.Provider, { value: setTimelineContextValue, children: _jsx(EditorPropsProvider, { children: _jsx(PrefetchProvider, { children: _jsx(NativeLayersProvider, { children: _jsx(CompositionManagerProvider, { numberOfAudioTags: numberOfAudioTags, children: _jsx(DurationsContextProvider, { children: _jsx(BufferingProvider, { children: children }) }) }) }) }) }) }) }) }));
};
