import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useCallback, useLayoutEffect, useMemo, useState, } from 'react';
export const RenderAssetManager = createContext({
    // Must be undefined, otherwise error in Player
    registerRenderAsset: () => undefined,
    unregisterRenderAsset: () => undefined,
    renderAssets: [],
});
export const RenderAssetManagerProvider = ({ children }) => {
    const [renderAssets, setRenderAssets] = useState([]);
    const registerRenderAsset = useCallback((renderAsset) => {
        setRenderAssets((assets) => {
            return [...assets, renderAsset];
        });
    }, []);
    const unregisterRenderAsset = useCallback((id) => {
        setRenderAssets((assts) => {
            return assts.filter((a) => a.id !== id);
        });
    }, []);
    useLayoutEffect(() => {
        if (typeof window !== 'undefined') {
            window.remotion_collectAssets = () => {
                setRenderAssets([]); // clear assets at next render
                return renderAssets;
            };
        }
    }, [renderAssets]);
    const contextValue = useMemo(() => {
        return {
            registerRenderAsset,
            unregisterRenderAsset,
            renderAssets,
        };
    }, [renderAssets, registerRenderAsset, unregisterRenderAsset]);
    return (_jsx(RenderAssetManager.Provider, { value: contextValue, children: children }));
};
