import { jsx as _jsx } from "react/jsx-runtime";
import React, { useCallback, useMemo, useState } from 'react';
export const SequenceManager = React.createContext({
    registerSequence: () => {
        throw new Error('SequenceManagerContext not initialized');
    },
    unregisterSequence: () => {
        throw new Error('SequenceManagerContext not initialized');
    },
    sequences: [],
});
export const SequenceVisibilityToggleContext = React.createContext({
    hidden: {},
    setHidden: () => {
        throw new Error('SequenceVisibilityToggle not initialized');
    },
});
export const SequenceManagerProvider = ({ children }) => {
    const [sequences, setSequences] = useState([]);
    const [hidden, setHidden] = useState({});
    const registerSequence = useCallback((seq) => {
        setSequences((seqs) => {
            return [...seqs, seq];
        });
    }, []);
    const unregisterSequence = useCallback((seq) => {
        setSequences((seqs) => seqs.filter((s) => s.id !== seq));
    }, []);
    const sequenceContext = useMemo(() => {
        return {
            registerSequence,
            sequences,
            unregisterSequence,
        };
    }, [registerSequence, sequences, unregisterSequence]);
    const hiddenContext = useMemo(() => {
        return {
            hidden,
            setHidden,
        };
    }, [hidden]);
    return (_jsx(SequenceManager.Provider, { value: sequenceContext, children: _jsx(SequenceVisibilityToggleContext.Provider, { value: hiddenContext, children: children }) }));
};
