import { jsx as _jsx } from "react/jsx-runtime";
import React, { useCallback, useEffect, useMemo, useRef, useState } from 'react';
const useBufferManager = () => {
    const [blocks, setBlocks] = useState([]);
    const [onBufferingCallbacks, setOnBufferingCallbacks] = useState([]);
    const [onResumeCallbacks, setOnResumeCallbacks] = useState([]);
    const buffering = useRef(false);
    const addBlock = useCallback((block) => {
        setBlocks((b) => [...b, block]);
        return {
            unblock: () => {
                setBlocks((b) => b.filter((bx) => bx !== block));
            },
        };
    }, []);
    const listenForBuffering = useCallback((callback) => {
        setOnBufferingCallbacks((c) => [...c, callback]);
        return {
            remove: () => {
                setOnBufferingCallbacks((c) => c.filter((cb) => cb !== callback));
            },
        };
    }, []);
    const listenForResume = useCallback((callback) => {
        setOnResumeCallbacks((c) => [...c, callback]);
        return {
            remove: () => {
                setOnResumeCallbacks((c) => c.filter((cb) => cb !== callback));
            },
        };
    }, []);
    useEffect(() => {
        if (blocks.length > 0) {
            onBufferingCallbacks.forEach((c) => c());
        }
        else {
            onResumeCallbacks.forEach((c) => c());
        }
    }, [blocks, onBufferingCallbacks, onResumeCallbacks]);
    return useMemo(() => {
        return { addBlock, listenForBuffering, listenForResume, buffering };
    }, [addBlock, buffering, listenForBuffering, listenForResume]);
};
export const BufferingContextReact = React.createContext(null);
export const BufferingProvider = ({ children }) => {
    const bufferManager = useBufferManager();
    return (_jsx(BufferingContextReact.Provider, { value: bufferManager, children: children }));
};
