import './asset-types.js';
import { Clipper } from './Clipper.js';
import { addSequenceStackTraces } from './enable-sequence-stack-traces.js';
import { useIsPlayer } from './is-player.js';
import { checkMultipleRemotionVersions } from './multiple-versions-warning.js';
import { Null } from './Null.js';
import { Sequence } from './Sequence.js';
checkMultipleRemotionVersions();
export * from './AbsoluteFill.js';
export * from './audio/index.js';
export { cancelRender } from './cancel-render.js';
export { Composition, } from './Composition.js';
export { getInputProps } from './config/input-props.js';
export { continueRender, delayRender } from './delay-render.js';
export * from './easing.js';
export * from './Folder.js';
export * from './freeze.js';
export { getRemotionEnvironment } from './get-remotion-environment.js';
export { getStaticFiles } from './get-static-files.js';
export * from './IFrame.js';
export { Img } from './Img.js';
export * from './internals.js';
export { interpolateColors } from './interpolate-colors.js';
export { Loop } from './loop/index.js';
export { interpolate, random, } from './no-react';
export { prefetch } from './prefetch.js';
export { registerRoot } from './register-root.js';
export { Sequence, } from './Sequence.js';
export { Series } from './series/index.js';
export * from './spring/index.js';
export { staticFile } from './static-file.js';
export * from './Still.js';
export { useBufferState } from './use-buffer-state';
export { useCurrentFrame } from './use-current-frame.js';
export { useCurrentScale, } from './use-current-scale';
export * from './use-video-config.js';
export * from './version.js';
export * from './video-config.js';
export * from './video/index.js';
export { watchStaticFile } from './watch-static-file.js';
export const Experimental = {
    /**
     * @description This is a special component that will cause Remotion to only partially capture the frame of the video.
     * @see [Documentation](https://www.remotion.dev/docs/clipper)
     */
    Clipper,
    /**
     * @description This is a special component, that, when rendered, will skip rendering the frame altogether.
     * @see [Documentation](https://www.remotion.dev/docs/null)
     */
    Null,
    useIsPlayer,
};
const proxyObj = {};
export const Config = new Proxy(proxyObj, {
    get(_, prop) {
        if (prop === 'Bundling' ||
            prop === 'Rendering' ||
            prop === 'Log' ||
            prop === 'Puppeteer' ||
            prop === 'Output') {
            return Config;
        }
        return () => {
            /* eslint-disable no-console */
            console.warn('⚠️  The CLI configuration has been extracted from Remotion Core.');
            console.warn('Update the import from the config file:');
            console.warn();
            console.warn('- Delete:');
            console.warn('import {Config} from "remotion";');
            console.warn('+ Replace:');
            console.warn('import {Config} from "@remotion/cli/config";');
            console.warn();
            console.warn('For more information, see https://www.remotion.dev/docs/4-0-migration.');
            /* eslint-enable no-console */
            process.exit(1);
        };
    },
});
addSequenceStackTraces(Sequence);
