import { jsx as _jsx } from "react/jsx-runtime";
/**
 * @vitest-environment jsdom
 */
import { render } from '@testing-library/react';
import { beforeEach, describe, expect, test, vitest } from 'vitest';
import { CanUseRemotionHooksProvider } from '../CanUseRemotionHooks.js';
import { RenderAssetManager } from '../RenderAssetManager.js';
import { ResolveCompositionConfig } from '../ResolveCompositionConfig.js';
import { AudioForRendering } from '../audio/AudioForRendering.js';
import { expectToThrow } from './expect-to-throw.js';
import { WrapSequenceContext } from './wrap-sequence-context.js';
let mockContext;
describe('Register and unregister asset', () => {
    function createMockContext() {
        const registerRenderAsset = vitest.fn();
        const unregisterRenderAsset = vitest.fn();
        window.remotion_audioEnabled = true;
        const MockProvider = ({ children }) => {
            return (_jsx(WrapSequenceContext, { children: _jsx(RenderAssetManager.Provider
                // eslint-disable-next-line react/jsx-no-constructed-context-values
                , { 
                    // eslint-disable-next-line react/jsx-no-constructed-context-values
                    value: {
                        registerRenderAsset,
                        unregisterRenderAsset,
                        renderAssets: [],
                    }, children: _jsx(ResolveCompositionConfig, { children: children }) }) }));
        };
        return {
            MockProvider,
            registerRenderAsset,
            unregisterRenderAsset,
        };
    }
    beforeEach(() => {
        mockContext = createMockContext();
    });
    test('register and unregister asset', () => {
        const props = {
            src: 'test',
            muted: false,
            volume: 50,
            onDuration: vitest.fn(),
        };
        const { unmount } = render(_jsx(CanUseRemotionHooksProvider, { children: _jsx(mockContext.MockProvider, { children: _jsx(AudioForRendering, { ...props }) }) }));
        expect(mockContext.registerRenderAsset).toHaveBeenCalled();
        unmount();
        expect(mockContext.unregisterRenderAsset).toHaveBeenCalled();
    });
    test('no src passed', () => {
        const props = {
            src: undefined,
            muted: false,
            volume: 50,
            onDuration: vitest.fn(),
        };
        expectToThrow(() => {
            render(_jsx(CanUseRemotionHooksProvider, { children: _jsx(mockContext.MockProvider, { children: _jsx(AudioForRendering, { ...props }) }) }));
        }, /No src passed/);
        expect(mockContext.registerRenderAsset).not.toHaveBeenCalled();
        expect(mockContext.unregisterRenderAsset).not.toHaveBeenCalled();
    });
});
