import { jsx as _jsx } from "react/jsx-runtime";
/**
 * @vitest-environment jsdom
 */
import { render } from '@testing-library/react';
import { describe, expect, test } from 'vitest';
import { Sequence } from '../Sequence.js';
import { Freeze } from '../freeze.js';
import { TimelineContext } from '../timeline-position-state.js';
import { useCurrentFrame } from '../use-current-frame.js';
import { expectToThrow } from './expect-to-throw.js';
import { WrapSequenceContext } from './wrap-sequence-context.js';
const TestComponent = () => {
    const frame = useCurrentFrame();
    return _jsx("div", { children: frame });
};
describe('Prop validation', () => {
    test('It should throw if Freeze has string as frame prop value', () => {
        expectToThrow(() => render(_jsx(WrapSequenceContext, { children: _jsx(Freeze, { frame: '0' }) })), /The 'frame' prop of <Freeze \/> must be a number, but is of type string/);
    });
    test('It should throw if Freeze has undefined as frame prop value', () => {
        expectToThrow(() => render(_jsx(WrapSequenceContext, { children: _jsx(Freeze, {}) })), /The <Freeze \/> component requires a 'frame' prop, but none was passed./);
    });
});
const timelineCtxValue = (frame) => ({
    rootId: '',
    frame: {
        'my-comp': frame,
    },
    playing: false,
    imperativePlaying: {
        current: false,
    },
    playbackRate: 1,
    setPlaybackRate: () => {
        throw new Error('playback rate');
    },
    audioAndVideoTags: { current: [] },
});
const renderForFrame = (frame, markup) => {
    return render(_jsx(WrapSequenceContext, { children: _jsx(TimelineContext.Provider, { value: timelineCtxValue(frame), children: markup }) }));
};
const Basic = () => {
    return (_jsx(Freeze, { frame: 300, children: _jsx(TestComponent, {}) }));
};
const WithSequence = () => {
    const SequenceFrom = 200;
    const FreezeFrame = 100;
    return (_jsx(WrapSequenceContext, { children: _jsx(Sequence, { from: SequenceFrom, layout: "none", children: _jsx(Freeze, { frame: FreezeFrame, children: _jsx(TestComponent, {}) }) }) }));
};
describe('Integration tests', () => {
    test('Basic test', () => {
        const { container } = renderForFrame(0, _jsx(Basic, {}));
        expect(container.innerHTML).toBe('<div>300</div>');
    });
    test('Should ignore a Sequence', () => {
        const { container } = renderForFrame(300, _jsx(WithSequence, {}));
        expect(container.innerHTML).toBe('<div>100</div>');
    });
});
