import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { renderToString } from 'react-dom/server';
import { expect, test } from 'vitest';
import { CanUseRemotionHooksProvider } from '../CanUseRemotionHooks.js';
import { Series } from '../series/index.js';
import { TimelineContext } from '../timeline-position-state.js';
import { useCurrentFrame } from '../use-current-frame.js';
import { WrapSequenceContext } from './wrap-sequence-context.js';
const First = () => {
    const frame = useCurrentFrame();
    return _jsx("div", { children: 'first ' + frame });
};
const Second = () => {
    const frame = useCurrentFrame();
    return _jsx("div", { children: 'second ' + frame });
};
const Third = () => {
    const frame = useCurrentFrame();
    return _jsx("div", { children: 'third ' + frame });
};
const Fourth = () => {
    const frame = useCurrentFrame();
    return _jsx("div", { children: 'fourth ' + frame });
};
const renderForFrame = (frame, markup) => {
    return renderToString(_jsx(CanUseRemotionHooksProvider, { children: _jsx(TimelineContext.Provider, { value: {
                rootId: '',
                frame: {
                    'my-comp': frame,
                },
                playing: false,
                imperativePlaying: {
                    current: false,
                },
                playbackRate: 1,
                setPlaybackRate: () => {
                    throw new Error('playback rate');
                },
                audioAndVideoTags: { current: [] },
            }, children: markup }) }));
};
test('Basic series test', () => {
    const outerHTML = renderForFrame(10, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(First, {}) }), _jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(Second, {}) }), _jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(Third, {}) })] }) }));
    expect(outerHTML).toBe('<div style="position:absolute;top:0;left:0;right:0;bottom:0;width:100%;height:100%;display:flex"><div>third 0</div></div>');
});
test('Should support fragments', () => {
    const outerHtml = renderForFrame(10, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(First, {}) }), _jsxs(_Fragment, { children: [_jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(Second, {}) }, "0"), _jsxs(_Fragment, { children: [_jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(Third, {}) }, "1"), _jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(Fourth, {}) }, "2")] })] })] }) }));
    expect(outerHtml).not.toBe('<div style="position:absolute;top:0;left:0;right:0;bottom:0;width:100%;height:100%;display:flex"><div>second 1</div></div>');
});
test('Should not allow foreign elements', () => {
    expect(() => {
        renderForFrame(0, _jsx(WrapSequenceContext, { children: _jsx(Series, { children: _jsx(First, {}) }) }));
    }).toThrow(/only accepts a/);
});
test('Should allow layout prop', () => {
    const outerHTML = renderForFrame(0, _jsx(WrapSequenceContext, { children: _jsx(Series, { children: _jsx(Series.Sequence, { durationInFrames: 1, children: _jsx(First, {}) }) }) }));
    expect(outerHTML).toBe('<div style="position:absolute;top:0;left:0;right:0;bottom:0;width:100%;height:100%;display:flex"><div>first 0</div></div>');
    const outerHTML2 = renderForFrame(0, _jsx(WrapSequenceContext, { children: _jsx(Series, { children: _jsx(Series.Sequence, { durationInFrames: 1, layout: "none", children: _jsx(First, {}) }) }) }));
    expect(outerHTML2).toBe('<div>first 0</div>');
});
test('Should render nothing after the end', () => {
    const outerHTML = renderForFrame(10, _jsx(WrapSequenceContext, { children: _jsx(Series, { children: _jsx(Series.Sequence, { durationInFrames: 1, children: _jsx(First, {}) }) }) }));
    expect(outerHTML).toBe('');
});
test('Should throw if invalid or no duration provided', () => {
    expect(() => {
        renderForFrame(10, _jsx(Series, { children: _jsx(Series.Sequence, { durationInFrames: NaN, children: _jsx(First, {}) }) }));
    }).toThrow(/The "durationInFrames" prop of a <Series.Sequence \/> component must be finite, but got NaN./);
    expect(() => {
        renderForFrame(10, _jsx(Series, { children: _jsx(Series.Sequence, { children: _jsx(First, {}) }) }));
    }).toThrow(/The "durationInFrames" prop of a <Series.Sequence \/> component is missing./);
});
test('Should allow whitespace', () => {
    const outerHtml = renderForFrame(11, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 10, children: _jsx(First, {}) }), ' ', _jsx(Series.Sequence, { durationInFrames: 10, children: _jsx(Second, {}) })] }) }));
    expect(outerHtml).toBe('<div style="position:absolute;top:0;left:0;right:0;bottom:0;width:100%;height:100%;display:flex"><div>second 1</div></div>');
});
test('Handle empty Series.Sequence', () => {
    expect(() => renderForFrame(11, _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 10, children: _jsx(First, {}) }), _jsx(Series.Sequence, { durationInFrames: 10 })] }))).toThrow(/A <Series.Sequence \/> component \(index = 1, duration = 10\) was detected to not have any children\. Delete it to fix this error\./);
});
test('Should allow negative overlap prop', () => {
    const outerHTML = renderForFrame(4, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 5, layout: "none", children: _jsx(First, {}) }), _jsx(Series.Sequence, { offset: -1, layout: "none", durationInFrames: 5, children: _jsx(Second, {}) })] }) }));
    expect(outerHTML).toBe('<div>first 4</div><div>second 0</div>');
});
test('Should allow positive overlap prop', () => {
    const outerHTML = renderForFrame(5, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 5, layout: "none", children: _jsx(First, {}) }), _jsx(Series.Sequence, { offset: 1, layout: "none", durationInFrames: 5, children: _jsx(Second, {}) })] }) }));
    expect(outerHTML).toBe('');
});
test('Should disallow NaN as offset prop', () => {
    expect(() => {
        renderForFrame(9, _jsx(Series, { children: _jsx(Series.Sequence, { offset: NaN, layout: "none", durationInFrames: 5, children: _jsx(Second, {}) }) }));
    }).toThrow(/The "offset" property of a <Series.Sequence \/> must not be NaN, but got NaN \(index = 0, duration = 5\)\./);
});
test('Should disallow Infinity as offset prop', () => {
    expect(() => {
        renderForFrame(9, _jsx(Series, { children: _jsx(Series.Sequence, { offset: Infinity, layout: "none", durationInFrames: 5, children: _jsx(Second, {}) }) }));
    }).toThrow(/The "offset" property of a <Series.Sequence \/> must be finite, but got Infinity \(index = 0, duration = 5\)\./);
});
test('Should disallow non-integer numbers as offset prop', () => {
    expect(() => {
        renderForFrame(9, _jsx(Series, { children: _jsx(Series.Sequence, { offset: Math.PI, layout: "none", durationInFrames: 5, children: _jsx(Second, {}) }) }));
    }).toThrow(/The "offset" property of a <Series.Sequence \/> must be finite, but got 3.141592653589793 \(index = 0, duration = 5\)\./);
});
test('Should cascade negative offset props', () => {
    const outerHTML = renderForFrame(9, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 5, layout: "none", children: _jsx(First, {}) }), _jsx(Series.Sequence, { offset: -1, layout: "none", durationInFrames: 5, children: _jsx(Second, {}) }), _jsx(Series.Sequence, { layout: "none", durationInFrames: 5, children: _jsx(Third, {}) })] }) }));
    expect(outerHTML).toBe('<div>third 0</div>');
});
test('Should cascade positive offset props', () => {
    const outerHTML = renderForFrame(11, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 5, layout: "none", children: _jsx(First, {}) }), _jsx(Series.Sequence, { offset: 1, layout: "none", durationInFrames: 5, children: _jsx(Second, {}) }), _jsx(Series.Sequence, { layout: "none", durationInFrames: 5, children: _jsx(Third, {}) })] }) }));
    expect(outerHTML).toBe('<div>third 0</div>');
});
test('Allow durationInFrames as Infinity for last Series.Sequence', () => {
    const outerHTML = renderForFrame(10, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(First, {}) }), _jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(Second, {}) }), _jsx(Series.Sequence, { durationInFrames: Infinity, children: _jsx(Third, {}) })] }) }));
    expect(outerHTML).toBe('<div style="position:absolute;top:0;left:0;right:0;bottom:0;width:100%;height:100%;display:flex"><div>third 0</div></div>');
});
test('Disallow durationInFrames as Infinity for first n-1 Series.Sequence', () => {
    expect(() => {
        renderForFrame(10, _jsx(WrapSequenceContext, { children: _jsxs(Series, { children: [_jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(First, {}) }), _jsx(Series.Sequence, { durationInFrames: Infinity, children: _jsx(Second, {}) }), _jsx(Series.Sequence, { durationInFrames: 5, children: _jsx(Third, {}) })] }) }));
    }).toThrow(/The "durationInFrames" prop of a <Series.Sequence \/> component must be finite, but got Infinity\./);
});
