import { jsx as _jsx } from "react/jsx-runtime";
/* eslint-disable @typescript-eslint/no-use-before-define */
import { forwardRef, useCallback, useContext } from 'react';
import { Sequence } from '../Sequence.js';
import { getAbsoluteSrc } from '../absolute-src.js';
import { calculateLoopDuration } from '../calculate-loop.js';
import { addSequenceStackTraces } from '../enable-sequence-stack-traces.js';
import { getRemotionEnvironment } from '../get-remotion-environment.js';
import { Loop } from '../loop/index.js';
import { usePreload } from '../prefetch.js';
import { useVideoConfig } from '../use-video-config.js';
import { validateMediaProps } from '../validate-media-props.js';
import { validateStartFromProps } from '../validate-start-from-props.js';
import { VideoForPreview } from './VideoForPreview.js';
import { VideoForRendering } from './VideoForRendering.js';
import { DurationsContext } from './duration-state.js';
const VideoForwardingFunction = (props, ref) => {
    var _a, _b;
    const { startFrom, endAt, name, pauseWhenBuffering, stack, _remotionInternalNativeLoopPassed, showInTimeline, ...otherProps } = props;
    const { loop, ...propsOtherThanLoop } = props;
    const { fps } = useVideoConfig();
    const environment = getRemotionEnvironment();
    const { durations, setDurations } = useContext(DurationsContext);
    if (typeof ref === 'string') {
        throw new Error('string refs are not supported');
    }
    if (typeof props.src !== 'string') {
        throw new TypeError(`The \`<Video>\` tag requires a string for \`src\`, but got ${JSON.stringify(props.src)} instead.`);
    }
    const preloadedSrc = usePreload(props.src);
    const onDuration = useCallback((src, durationInSeconds) => {
        setDurations({ type: 'got-duration', durationInSeconds, src });
    }, [setDurations]);
    const durationFetched = (_a = durations[getAbsoluteSrc(preloadedSrc)]) !== null && _a !== void 0 ? _a : durations[getAbsoluteSrc(props.src)];
    if (loop && durationFetched !== undefined) {
        const mediaDuration = durationFetched * fps;
        return (_jsx(Loop, { durationInFrames: calculateLoopDuration({
                endAt,
                mediaDuration,
                playbackRate: (_b = props.playbackRate) !== null && _b !== void 0 ? _b : 1,
                startFrom,
            }), layout: "none", name: name, children: _jsx(Video, { ...propsOtherThanLoop, ref: ref, _remotionInternalNativeLoopPassed: true }) }));
    }
    if (typeof startFrom !== 'undefined' || typeof endAt !== 'undefined') {
        validateStartFromProps(startFrom, endAt);
        const startFromFrameNo = startFrom !== null && startFrom !== void 0 ? startFrom : 0;
        const endAtFrameNo = endAt !== null && endAt !== void 0 ? endAt : Infinity;
        return (_jsx(Sequence, { layout: "none", from: 0 - startFromFrameNo, showInTimeline: false, durationInFrames: endAtFrameNo, name: name, children: _jsx(Video, { pauseWhenBuffering: pauseWhenBuffering !== null && pauseWhenBuffering !== void 0 ? pauseWhenBuffering : false, ...otherProps, ref: ref }) }));
    }
    validateMediaProps(props, 'Video');
    if (environment.isRendering) {
        return (_jsx(VideoForRendering, { onDuration: onDuration, ...otherProps, ref: ref }));
    }
    return (_jsx(VideoForPreview, { onlyWarnForMediaSeekingError: false, ...otherProps, ref: ref, 
        // Proposal: Make this default to true in v5
        pauseWhenBuffering: pauseWhenBuffering !== null && pauseWhenBuffering !== void 0 ? pauseWhenBuffering : false, onDuration: onDuration, _remotionInternalStack: stack !== null && stack !== void 0 ? stack : null, _remotionInternalNativeLoopPassed: _remotionInternalNativeLoopPassed !== null && _remotionInternalNativeLoopPassed !== void 0 ? _remotionInternalNativeLoopPassed : false, showInTimeline: showInTimeline !== null && showInTimeline !== void 0 ? showInTimeline : true }));
};
/**
 * @description allows you to include a video file in your Remotion project. It wraps the native HTMLVideoElement.
 * @see [Documentation](https://www.remotion.dev/docs/video)
 */
export const Video = forwardRef(VideoForwardingFunction);
addSequenceStackTraces(Video);
