import { jsx as _jsx } from "react/jsx-runtime";
// This is used for when other reconcilers are being used
// such as in React Three Fiber. All the contexts need to be passed again
// for them to be useable
import React, { useMemo } from 'react';
import { CanUseRemotionHooks } from './CanUseRemotionHooks.js';
import { CompositionManager } from './CompositionManagerContext.js';
import { NativeLayersContext } from './NativeLayers.js';
import { RenderAssetManager } from './RenderAssetManager.js';
import { ResolveCompositionContext } from './ResolveCompositionConfig.js';
import { SequenceContext } from './SequenceContext.js';
import { SequenceManager } from './SequenceManager.js';
import { BufferingContextReact } from './buffering.js';
import { NonceContext } from './nonce.js';
import { PreloadContext } from './prefetch-state.js';
import { SetTimelineContext, TimelineContext, } from './timeline-position-state.js';
export function useRemotionContexts() {
    const compositionManagerCtx = React.useContext(CompositionManager);
    const timelineContext = React.useContext(TimelineContext);
    const setTimelineContext = React.useContext(SetTimelineContext);
    const sequenceContext = React.useContext(SequenceContext);
    const nonceContext = React.useContext(NonceContext);
    const canUseRemotionHooksContext = React.useContext(CanUseRemotionHooks);
    const nativeLayersContext = React.useContext(NativeLayersContext);
    const preloadContext = React.useContext(PreloadContext);
    const resolveCompositionContext = React.useContext(ResolveCompositionContext);
    const renderAssetManagerContext = React.useContext(RenderAssetManager);
    const sequenceManagerContext = React.useContext(SequenceManager);
    const bufferManagerContext = React.useContext(BufferingContextReact);
    return useMemo(() => ({
        compositionManagerCtx,
        timelineContext,
        setTimelineContext,
        sequenceContext,
        nonceContext,
        canUseRemotionHooksContext,
        nativeLayersContext,
        preloadContext,
        resolveCompositionContext,
        renderAssetManagerContext,
        sequenceManagerContext,
        bufferManagerContext,
    }), [
        compositionManagerCtx,
        nonceContext,
        sequenceContext,
        setTimelineContext,
        timelineContext,
        canUseRemotionHooksContext,
        nativeLayersContext,
        preloadContext,
        resolveCompositionContext,
        renderAssetManagerContext,
        sequenceManagerContext,
        bufferManagerContext,
    ]);
}
export const RemotionContextProvider = (props) => {
    const { children, contexts } = props;
    return (_jsx(CanUseRemotionHooks.Provider, { value: contexts.canUseRemotionHooksContext, children: _jsx(NonceContext.Provider, { value: contexts.nonceContext, children: _jsx(NativeLayersContext.Provider, { value: contexts.nativeLayersContext, children: _jsx(PreloadContext.Provider, { value: contexts.preloadContext, children: _jsx(CompositionManager.Provider, { value: contexts.compositionManagerCtx, children: _jsx(SequenceManager.Provider, { value: contexts.sequenceManagerContext, children: _jsx(RenderAssetManager.Provider, { value: contexts.renderAssetManagerContext, children: _jsx(ResolveCompositionContext.Provider, { value: contexts.resolveCompositionContext, children: _jsx(TimelineContext.Provider, { value: contexts.timelineContext, children: _jsx(SetTimelineContext.Provider, { value: contexts.setTimelineContext, children: _jsx(SequenceContext.Provider, { value: contexts.sequenceContext, children: _jsx(BufferingContextReact.Provider, { value: contexts.bufferManagerContext, children: children }) }) }) }) }) }) }) }) }) }) }) }));
};
